@@ -1,12 +1,12 @@
 package Email::MIME::Kit::Renderer::Text::Template;
-BEGIN {
-  $Email::MIME::Kit::Renderer::Text::Template::VERSION = '1.101300';
+{
+  $Email::MIME::Kit::Renderer::Text::Template::VERSION = '1.101301';
 }
 use Moose;
 with 'Email::MIME::Kit::Role::Renderer';
 # ABSTRACT: render parts of your mail with Text::Template
 
-use Text::Template ();
+use Module::Runtime ();
 
 sub _enref_as_needed {
   my ($self, $hash) = @_;
@@ -19,6 +19,14 @@ sub _enref_as_needed {
   return \%return;
 }
 
+
+has template_class => (
+  is  => 'ro',
+  isa => 'Str',
+  default => 'Text::Template',
+);
+
+
 has template_args => (
   is  => 'ro',
   isa => 'HashRef',
@@ -31,13 +39,17 @@ sub render  {
     (map {; $_ => ref $args->{$_} ? $args->{$_} : \$args->{$_} } keys %$args),
   });
 
-  my $result = Text::Template->fill_this_in(
+  my $template_class = $self->template_class;
+  Module::Runtime::require_module($template_class);
+
+  my $result = $template_class->fill_this_in(
     $$input_ref,
     %{ $self->{template_args} || {} },
     HASH   => $hash,
     BROKEN => sub { my %hash = @_; die $hash{error}; },
   );
 
+  # :-(  -- rjbs, 2012-10-01
   die $Text::Template::ERROR unless defined $result;
 
   return \$result;
@@ -46,6 +58,7 @@ sub render  {
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -54,18 +67,29 @@ Email::MIME::Kit::Renderer::Text::Template - render parts of your mail with Text
 
 =head1 VERSION
 
-version 1.101300
+version 1.101301
+
+=head1 ATTRIBUTES
+
+=head2 template_class
+
+This attribute stores the name of the class that will be standing in for
+Text::Template, if any.  It defaults, obviously, to Text::Template.
+
+=head2 template_args
+
+These are the arguments that will be passed to C<fill_this_in> along with the
+template, input, and a few required handlers.
 
 =head1 AUTHOR
 
-  Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo Signes.
+This software is copyright (c) 2012 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
